@@ -1,7 +1,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2020 David R. MacIver
+# Most of this work is copyright (C) 2013-2021 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -26,15 +26,12 @@ definitions it links to.  If not, report the bug!
 import os.path
 import string
 
-import hypothesis.internal.conjecture.utils as cu
-import hypothesis.strategies._internal.core as st
-from hypothesis._settings import note_deprecation
 from hypothesis.errors import InvalidArgument
-from hypothesis.internal.reflection import deprecated_posargs
-from hypothesis.strategies._internal.ipaddress import ip_addresses
+from hypothesis.internal.conjecture import utils as cu
+from hypothesis.strategies._internal import core as st
 from hypothesis.strategies._internal.strategies import SearchStrategy
 
-URL_SAFE_CHARACTERS = frozenset(string.ascii_letters + string.digits + "$-_.+!*'(),")
+URL_SAFE_CHARACTERS = frozenset(string.ascii_letters + string.digits + "$-_.+!*'(),~")
 
 
 # This file is sourced from http://data.iana.org/TLD/tlds-alpha-by-domain.txt
@@ -134,8 +131,7 @@ class DomainNameStrategy(SearchStrategy):
         return domain
 
 
-@st.defines_strategy_with_reusable_values
-@deprecated_posargs
+@st.defines_strategy(force_reusable_values=True)
 def domains(
     *, max_length: int = 255, max_element_length: int = 63
 ) -> SearchStrategy[str]:
@@ -145,7 +141,7 @@ def domains(
     )
 
 
-@st.defines_strategy_with_reusable_values
+@st.defines_strategy(force_reusable_values=True)
 def urls() -> SearchStrategy[str]:
     """A strategy for :rfc:`3986`, generating http/https URLs."""
 
@@ -159,23 +155,3 @@ def urls() -> SearchStrategy[str]:
     return st.builds(
         "{}://{}{}/{}".format, schemes, domains(), st.just("") | ports, paths
     )
-
-
-@st.defines_strategy_with_reusable_values
-def ip4_addr_strings() -> SearchStrategy[str]:
-    note_deprecation(
-        "Use `ip_addresses(v=4).map(str)` instead of `ip4_addr_strings()`; "
-        "the provisional strategy is less flexible and will be removed.",
-        since="2020-01-21",
-    )
-    return ip_addresses(v=4).map(str)
-
-
-@st.defines_strategy_with_reusable_values
-def ip6_addr_strings() -> SearchStrategy[str]:
-    note_deprecation(
-        "Use `ip_addresses(v=6).map(str)` instead of `ip6_addr_strings()`; "
-        "the provisional strategy is less flexible and will be removed.",
-        since="2020-01-21",
-    )
-    return ip_addresses(v=6).map(str)
