@@ -50,7 +50,6 @@ from uuid import UUID
 
 import attr
 
-from hypothesis._settings import note_deprecation
 from hypothesis.control import cleanup, note, reject
 from hypothesis.errors import InvalidArgument, ResolutionFailed
 from hypothesis.internal.cache import LRUReusedCache
@@ -74,7 +73,6 @@ from hypothesis.internal.floats import (
 )
 from hypothesis.internal.reflection import (
     define_function_signature,
-    deprecated_posargs,
     get_pretty_function_description,
     is_typed_named_tuple,
     nicerepr,
@@ -298,11 +296,55 @@ def none() -> SearchStrategy[None]:
     return just(None)
 
 
+T4 = TypeVar("T4")
+T5 = TypeVar("T5")
+
+
 @overload
 def one_of(args: Sequence[SearchStrategy[Any]]) -> SearchStrategy[Any]:
     raise NotImplementedError
 
 
+@overload  # noqa: F811
+def one_of(a1: SearchStrategy[Ex]) -> SearchStrategy[Ex]:
+    raise NotImplementedError
+
+
+@overload  # noqa: F811
+def one_of(
+    a1: SearchStrategy[Ex], a2: SearchStrategy[K]
+) -> SearchStrategy[Union[Ex, K]]:
+    raise NotImplementedError
+
+
+@overload  # noqa: F811
+def one_of(
+    a1: SearchStrategy[Ex], a2: SearchStrategy[K], a3: SearchStrategy[V]
+) -> SearchStrategy[Union[Ex, K, V]]:
+    raise NotImplementedError
+
+
+@overload  # noqa: F811
+def one_of(
+    a1: SearchStrategy[Ex],
+    a2: SearchStrategy[K],
+    a3: SearchStrategy[V],
+    a4: SearchStrategy[T4],
+) -> SearchStrategy[Union[Ex, K, V, T4]]:
+    raise NotImplementedError
+
+
+@overload  # noqa: F811
+def one_of(
+    a1: SearchStrategy[Ex],
+    a2: SearchStrategy[K],
+    a3: SearchStrategy[V],
+    a4: SearchStrategy[T4],
+    a5: SearchStrategy[T5],
+) -> SearchStrategy[Union[Ex, K, V, T4, T5]]:
+    raise NotImplementedError
+
+
 @overload  # noqa: F811
 def one_of(*args: SearchStrategy[Any]) -> SearchStrategy[Any]:
     raise NotImplementedError
@@ -425,7 +467,6 @@ def booleans() -> SearchStrategy[bool]:
 
 @cacheable
 @defines_strategy(force_reusable_values=True)
-@deprecated_posargs
 def floats(
     min_value: Optional[Real] = None,
     max_value: Optional[Real] = None,
@@ -704,7 +745,6 @@ def identity(x):
 
 @cacheable
 @defines_strategy()
-@deprecated_posargs
 def lists(
     elements: SearchStrategy[Ex],
     *,
@@ -824,7 +864,6 @@ def lists(
 
 @cacheable
 @defines_strategy()
-@deprecated_posargs
 def sets(
     elements: SearchStrategy[Ex],
     *,
@@ -847,7 +886,6 @@ def sets(
 
 @cacheable
 @defines_strategy()
-@deprecated_posargs
 def frozensets(
     elements: SearchStrategy[Ex],
     *,
@@ -877,7 +915,6 @@ class PrettyIter:
 
 
 @defines_strategy()
-@deprecated_posargs
 def iterables(
     elements: SearchStrategy[Ex],
     *,
@@ -945,7 +982,6 @@ def fixed_dictionaries(
 
 @cacheable
 @defines_strategy()
-@deprecated_posargs
 def dictionaries(
     keys: SearchStrategy[Ex],
     values: SearchStrategy[T],
@@ -981,7 +1017,6 @@ def dictionaries(
 
 @cacheable
 @defines_strategy(force_reusable_values=True)
-@deprecated_posargs
 def characters(
     *,
     whitelist_categories: Optional[Sequence[str]] = None,
@@ -1088,7 +1123,6 @@ def characters(
 
 @cacheable
 @defines_strategy(force_reusable_values=True)
-@deprecated_posargs
 def text(
     alphabet: Union[Sequence[str], SearchStrategy[str]] = characters(
         blacklist_categories=("Cs",)
@@ -1144,7 +1178,6 @@ def text(
 
 @cacheable
 @defines_strategy()
-@deprecated_posargs
 def from_regex(
     regex: Union[AnyStr, Pattern[AnyStr]], *, fullmatch: bool = False
 ) -> SearchStrategy[AnyStr]:
@@ -1185,7 +1218,6 @@ def from_regex(
 
 @cacheable
 @defines_strategy(force_reusable_values=True)
-@deprecated_posargs
 def binary(
     *,
     min_size: int = 0,
@@ -1212,7 +1244,7 @@ def binary(
 def randoms(
     *,
     note_method_calls: bool = False,
-    use_true_random: Optional[bool] = None,
+    use_true_random: bool = False,
 ) -> SearchStrategy[random.Random]:
     """Generates instances of ``random.Random``. The generated Random instances
     are of a special HypothesisRandom subclass.
@@ -1228,16 +1260,8 @@ def randoms(
       flag should only be set to True when your code relies on the distribution
       of values for correctness.
     """
-    if use_true_random is None:
-        note_deprecation(
-            """Defaulting to old behaviour of use_true_random=True. If you want
-            to keep that behaviour, set use_true_random=True explicitly. If you
-            want the new behaviour (which will become the default in future),
-            set use_true_random=False.""",
-            since="2020-06-30",
-            has_codemod=False,
-        )
-        use_true_random = True
+    check_type(bool, note_method_calls, "note_method_calls")
+    check_type(bool, use_true_random, "use_true_random")
 
     from hypothesis.strategies._internal.random import RandomStrategy
 
@@ -1639,7 +1663,6 @@ def _from_type(thing: Type[Ex]) -> SearchStrategy[Ex]:
 
 @cacheable
 @defines_strategy(force_reusable_values=True)
-@deprecated_posargs
 def fractions(
     min_value: Optional[Union[Real, str]] = None,
     max_value: Optional[Union[Real, str]] = None,
@@ -1749,7 +1772,6 @@ def _as_finite_decimal(
 
 @cacheable
 @defines_strategy(force_reusable_values=True)
-@deprecated_posargs
 def decimals(
     min_value: Optional[Union[Real, str]] = None,
     max_value: Optional[Union[Real, str]] = None,
@@ -1837,7 +1859,6 @@ def decimals(
     return strat | (sampled_from(special) if special else nothing())
 
 
-@deprecated_posargs
 def recursive(
     base: SearchStrategy[Ex],
     extend: Callable[[SearchStrategy[Any]], SearchStrategy[T]],
@@ -1960,7 +1981,6 @@ def composite(f: Callable[..., Ex]) -> Callable[..., SearchStrategy[Ex]]:
 
 @defines_strategy(force_reusable_values=True)
 @cacheable
-@deprecated_posargs
 def complex_numbers(
     *,
     min_magnitude: Real = 0,
@@ -1994,8 +2014,6 @@ def complex_numbers(
     check_valid_magnitude(min_magnitude, "min_magnitude")
     check_valid_magnitude(max_magnitude, "max_magnitude")
     check_valid_interval(min_magnitude, max_magnitude, "min_magnitude", "max_magnitude")
-    if min_magnitude is None:
-        min_magnitude = 0
     if max_magnitude == math.inf:
         max_magnitude = None
 
@@ -2046,7 +2064,6 @@ def complex_numbers(
     return constrained_complex()
 
 
-@deprecated_posargs
 def shared(
     base: SearchStrategy[Ex],
     *,
@@ -2073,7 +2090,6 @@ def shared(
 
 @cacheable
 @defines_strategy(force_reusable_values=True)
-@deprecated_posargs
 def uuids(*, version: Optional[int] = None) -> SearchStrategy[UUID]:
     """Returns a strategy that generates :class:`UUIDs <uuid.UUID>`.
 
@@ -2118,7 +2134,6 @@ class RunnerStrategy(SearchStrategy):
 
 
 @defines_strategy(force_reusable_values=True)
-@deprecated_posargs
 def runner(*, default: Any = not_set) -> SearchStrategy[Any]:
     """A strategy for getting "the current test runner", whatever that may be.
     The exact meaning depends on the entry point, but it will usually be the
@@ -2241,26 +2256,12 @@ def register_type_strategy(
         raise InvalidArgument("strategy=%r must not be empty")
     elif types.has_type_arguments(custom_type):
         origin = getattr(custom_type, "__origin__", None)
-        if callable(strategy):
-            strategy_repr = get_pretty_function_description(strategy)
-        else:
-            strategy_repr = repr(strategy)
-        note_deprecation(
-            "Registering a generic type with arguments (%r) is deprecated, and "
-            "will be an error in future, because the resolution logic is badly "
-            "broken.  Instead, register a function for the origin type (%r) "
-            "which can inspect specific type objects and return a strategy.  "
-            "%s will be registered for any type arguments."
-            % (custom_type, origin, strategy_repr),
-            since="2020-08-17",
-            has_codemod=False,
+        raise InvalidArgument(
+            f"Cannot register generic type {custom_type!r}, because it has type "
+            "arguments which would not be handled.  Instead, register a function "
+            f"for {origin!r} which can inspect specific type objects and return a "
+            "strategy."
         )
-        if origin in types._global_type_lookup:
-            raise InvalidArgument(
-                "Cannot register %r, because the without-arguments form %r already "
-                "has a registered strategy %s" % (custom_type, origin, strategy_repr)
-            )
-        custom_type = origin
 
     types._global_type_lookup[custom_type] = strategy
     from_type.__clear_cache()  # type: ignore
@@ -2320,7 +2321,6 @@ def emails() -> SearchStrategy[str]:
 
 
 @defines_strategy()
-@deprecated_posargs
 def functions(
     *,
     like: Callable[..., Any] = lambda: None,
